% MATLAB code
% File: Causalityfilter.m
%
% function [Fy_doesntcause_x,Fx_doesntcause_y,py_doesnt_cause_x,px_doesnt_cause_y]=asnlmg(x,y,t1,t2,c1,c2,signx,signy);
% INPUT:
% x, y  = the series to be tested
% t1,t2 = the delay values in the Mackey-Glass model
% c1,c2 = the exponents in the nonlinear terms of the M-G model:
%    X(t) = a(1,1)[X(t-t1)/{1+X(t-t1)^c1}-d(1,1)X(t-1)+a(1,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(1,2)X_{t-1}+mu(t)
%    Y(t) = a(2,1)[X(t-t1)/{1+X(t-t1)^c1}-d(2,1)X(t-1)+a(2,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(2,2)X_{t-1}+mu(t)
%    with mu(t) ~(i.i.d.) N(0,1)
%
% The variables signx,signy control which of the four possible asymetries
% to test for causality. +1 for "+", -1 for "-". That is, signx=1 causes the code
% to ignore any observations in which the returns of the x-variable are
% negative (-), or any observations which are related to negative x-returns
% via the nonlinear term on the right-hand side of the M-G model.
%
% EXACTLY ONE of the signx, signy inputs must be zero (e.g., if signx=0
% then we are testing for causality from y to x).
%
% OUTPUT: the F-values and p-values describing the statistical
% significance of the zero hypotheses (x doesn't cause y, y doesn't cause x).
% Low p-values suggest that the zero hypothesis is to be rejected.
% See also Granger causality test.
%
% EXAMPLES:
%   [f1,f2,p1,p2]=asnlmg(x,y,1,1,2,2,-1,0); % tests whether negative
%                                           % x-series terms cause the y series
%   [f1,f2,p1,p2]=asnlmg(x,y,1,3,2,2, 1,0); % tests whether positive
%                                                   %x-series terms cause the y series
%   [f1,f2,p1,p2]=asnlmg(x,y,1,1,2,2,0,-1); % tests whether negative
%                                           % y series terms cause the x series
%   [f1,f2,p1,p2]=asnlmg(x,y,1,1,2,2,0,1);  % tests whether positive
%                                           % y series terms cause the x series
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load  C:\...\COPchanges.dat;
load  C:\...\SP500percentage.dat;
x = COPchanges(1:431,1);
y = SP500percentage(1:431,1);
%[f1,f2,p1,p2] = asnlmg(x,y,1,1,2,2,-1,0);%
%[f1,f2,p1,p2] = asnlmg(x,y,1,1,2,2,1,0);
%[f1,f2,p1,p2] = asnlmg(x,y,1,1,3,2,0,-1);%
[f1,f2,p1,p2]  = asnlmg(x,y,1,1,3,2,0,1);