% MATLAB code
% File: Causalitysymmetry.m
%
% function [Fx_notcaused_by_y,Fy_notcaused_by_x,py_doesnt_cause_x,px_doesnt_cause_y,est_ax,est_ay]=nlmg(x,y,t1,t2,c1,c2);
%
% GRANGER-style causality test for Mackey-Glass model - 
%   testing for statistical significance of the nonlinear terms ONLY
%
% References: 
% Hristu-Varsakelis, D. and Kyrtsou, C. (2008).
%   Evidence for nonlinear asymmetric causality in US inflation, metal and
%   stock returns, Discrete Dynamics in Nature and Society.
%   Available at: https://www.hindawi.com/journals/ddns/2008/138547/.
%   Doi:10.1155/2008/138547
% Hristu-Varsakelis, D. and Kyrtsou, C. (2010). 
%   Testing for Granger causality in the presence of chaotic dynamics, 
%   Brussels Economic Review, 53(2), 323-327. 
% Anoruo, E. (2011).
%   Testing for linear and nonlinear causality between crude oil price changes
%   and stock market returns. 
%   Int. J. of Economic Sciences and Applied Research, 4(3), 75-92.
%
% INPUT:
% x, y  = the series to be tested
% t1,t2 = the delay values in the Mackey-Glass model:
%    X(t) = a(1,1)[X(t-t1)/{1+X(t-t1)^c1}-d(1,1)X(t-1)+a(1,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(1,2)X_{t-1}+mu(t)
%    Y(t) = a(2,1)[X(t-t1)/{1+X(t-t1)^c1}-d(2,1)X(t-1)+a(2,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(2,2)X_{t-1}+mu(t)
%    with mu(t) ~(i.i.d.) N(0,1)

% c1,c2 = the exponents in the nonlinear terms of the M-G model
%
% OUTPUT: the F-values and p-values describing the statistical
% significance of the zero hypotheses (x doesn't cause y, y doesn't cause x). 
% Low p-values suggest that the zero hypothesis is to be rejected. 
% See also Granger causality test.
%
% est_ax, est_ay hold the estimated (best fit) coefficients of the M-G model:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load  C:\...\COPchanges.dat;
load  C:\...\SP500percentage.dat;
x = COPchanges(1:431,1);
y = SP500percentage(1:431,1);
[Fx_notcaused_by_y,Fy_notcaused_by_x,py_doesnt_cause_x,px_doesnt_cause_y,est_ax,est_ay]=nlmg(x,y,10,1,4,1);
