% MATLAB code
% File: MODELSELECTION.m
%
% function [Rkurtosis,Rskew,Rschwarzx,Rschwarzy]=mgparams(x,y,t1,t2,c1,c2)
%
% This function estimates a Mackey-Glass model with parameters t1,t2, and
% c1,c2, given the series x and y, and returns a statistical evaluation of
% the fit. Its purpose is to facilitate the search for "good" model
% parameters.
%
% INPUT:
% x, y  = the series to be tested; x = SP500percentage, y = COPchanges, 
% t1,t2 = the delay values in the Mackey-Glass model:
%    X(t) = a(1,1)[X(t-t1)/{1+X(t-t1)^c1}-d(1,1)X(t-1)+a(1,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(1,2)X_{t-1}+mu(t)
%    Y(t) = a(2,1)[X(t-t1)/{1+X(t-t1)^c1}-d(2,1)X(t-1)+a(2,2)[Y(t-t2)/{1+Y(t-t2)^c2}
%           -d(2,2)X_{t-1}+mu(t)
%    with mu(t) ~(i.i.d.) N(0,1)
%
% c1,c2 = the exponents in the nonlinear terms of the M-G model
%
% OUTPUT: Kurtosis, Skewness and Schwarz criterion of the residuals.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load  C:\...\COPchanges.dat;
load  C:\...\SP500percentage.dat;
y = COPchanges(1:431,1);
x = SP500percentag(1:431,1);
% [Rkurtosis,Rskew,Rschwarzx,Rschwarzy] = mgparams(x,y,t1,t2,c1,c2)
[Rkurtosis,Rskew,Rschwarzx,Rschwarzy] = mgparams(x,y,1,1,2,2)
